# Code of Conduct

## Our Pledge

We want this project to be a respectful, inclusive, and harassment-free space for everyone.

## Our Standards

Examples of behavior that contributes to a positive environment:

- being respectful and constructive
- assuming good intent
- accepting feedback gracefully
- focusing on what is best for the community

Examples of unacceptable behavior:

- harassment, intimidation, or discrimination
- personal attacks or insulting language
- doxxing or sharing private information
- disruptive trolling or bad-faith engagement

## Enforcement

Project maintainers are responsible for clarifying and enforcing these standards.

## Reporting

Report Code of Conduct issues to: marklubin@pm.me

All reports will be reviewed and handled confidentially.
